@@ -38,8 +38,25 @@ def get_parser():
         action="store_true",
     )
 
+    deploy_group = parser.add_argument_group("DEPLOY")
+    deploy_group.add_argument(
+        "--remote",
+        dest="template",
+        help="Template the repository first to create a remote to clone. GITHUB_TOKEN is required.",
+        default=False,
+        action="store_true",
+    )
+
+    deploy_group.add_argument(
+        "--name",
+        dest="name",
+        help="A custom name for your template repository, <org/username>/<repository>.",
+    )
+
     # Logging
-    parser.add_argument(
+    logging_group = parser.add_argument_group("LOGGING")
+
+    logging_group.add_argument(
         "--verbose",
         dest="verbose",
         help="verbose output for logging.",
@@ -47,7 +64,7 @@ def get_parser():
         action="store_true",
     )
 
-    parser.add_argument(
+    logging_group.add_argument(
         "--log-disable-color",
         dest="disable_color",
         default=False,
@@ -55,7 +72,7 @@ def get_parser():
         action="store_true",
     )
 
-    parser.add_argument(
+    logging_group.add_argument(
         "--log-use-threads",
         dest="use_threads",
         action="store_true",
@@ -120,7 +137,12 @@ def main():
 
     # Instantiate and depoy the runner
     runner = ProviderRunner()
-    runner.deploy(source=args.repo, dest=args.dest, force=args.force)
+
+    # First template the repository, if desired
+    repo = args.repo
+    if args.template:
+        repo = runner.template(source=args.repo, name=args.name)
+    runner.deploy(source=repo, dest=args.dest, force=args.force)
 
 
 if __name__ == "__main__":
